@@ -18,9 +18,13 @@ from faust.types import CodecArg
 from faust.types.models import ModelT
 
 from delphai_utils.config import get_config
+from delphai_utils.patches import aiokafka_patch
+
 
 logger = logging.getLogger(__name__)
 
+aiokafka_patch()
+
 
 def is_port_free(host, port):
     """
