@@ -1,36 +1,40 @@
 import collections.abc
+import json
+import logging
+import os
+from base64 import b64encode
+from time import perf_counter
 from typing import Dict, Iterable, List, Union
+from urllib.parse import urlparse
+
+from google.api.http_pb2 import HttpRule
+from google.protobuf import symbol_database
 from google.protobuf.descriptor import (
     FieldDescriptor,
     FileDescriptor,
     MethodDescriptor,
     ServiceDescriptor,
 )
+from google.protobuf.descriptor_pb2 import MethodOptions
 from google.protobuf.json_format import MessageToDict
 from google.protobuf.message import Message
 from grpc import Channel, StatusCode
-from delphai_utils.logging import logging
-from google.protobuf.descriptor_pb2 import MethodOptions
-from google.api.http_pb2 import HttpRule
+from grpc.experimental.aio import AioRpcError, insecure_channel
+from hypercorn.asyncio import serve
+from hypercorn.config import Config
+from jose.exceptions import JWTError
 from starlette.applications import Starlette
-from starlette.requests import Request
-from starlette.responses import JSONResponse
 from starlette.exceptions import HTTPException
 from starlette.middleware.base import BaseHTTPMiddleware
-from grpc.experimental.aio import insecure_channel, AioRpcError
 from starlette.middleware.cors import CORSMiddleware
-import os
-from google.protobuf import symbol_database
-from hypercorn.config import Config
-from hypercorn.asyncio import serve
-from urllib.parse import urlparse
-from time import perf_counter
-import json
-from base64 import b64encode
-from starlette_prometheus import metrics, PrometheusMiddleware
+from starlette.requests import Request
+from starlette.responses import JSONResponse
+from starlette_prometheus import PrometheusMiddleware, metrics
+
+from delphai_utils.keycloak import PublicKeyFetchError, decode_token
 from delphai_utils.utils import generate_default_message
-from jose.exceptions import JWTError
-from delphai_utils.keycloak import decode_token, PublicKeyFetchError
+
+logger = logging.getLogger(__name__)
 
 supported_methods = ["get", "put", "post", "delete", "patch"]
 status_map = {
@@ -62,7 +66,7 @@ class AccessLogMiddleware(BaseHTTPMiddleware):
             path = urlparse(str(request.url)).path
             end = perf_counter()
             elapsed = round((end - start) * 1000, 2)
-            logging.info(
+            logger.info(
                 f"[{response.status_code}] {request.method} {path} [{elapsed}ms]"
             )
         return response
@@ -101,7 +105,7 @@ async def http_exception(request, exc):
         status_code = 404
     else:
         path = urlparse(str(request.url)).path
-        logging.error(f"[{exc.status_code}] {request.method} {path} - {exc.detail}")
+        logger.error(f"[{exc.status_code}] {request.method} {path} - {exc.detail}")
         detail = exc.detail
         status_code = exc.status_code
     return JSONResponse(
@@ -130,23 +134,23 @@ def get_http_handlers(
         input = {**request.path_params, **request.query_params, **body}
         metadata = {}
         if "Authorization" not in request.headers:
-            logging.warn("no authorization header")
+            logger.warn("no authorization header")
         else:
             authorization_header = request.headers.get("Authorization")
             if "Bearer " not in authorization_header:
                 error_msg = "Authorization header has the wrong format."
-                logging.error(error_msg, authorization_header)
+                logger.error(error_msg, authorization_header)
                 raise HTTPException(401, detail=error_msg)
             _, access_token = authorization_header.split("Bearer ")
             try:
                 decoded_access_token = await decode_token(access_token)
             except JWTError as ex:
                 error_msg = f"Error decoding the token: {ex}"
-                logging.error(error_msg)
+                logger.error(error_msg)
                 raise HTTPException(401, detail=error_msg)
             except PublicKeyFetchError as ex:
                 error_msg = f"Error fetching jwk from keycloak: {ex}"
-                logging.error(error_msg)
+                logger.error(error_msg)
                 raise HTTPException(502, detail=error_msg)
             user = {
                 "https://delphai.com/mongo_user_id": decoded_access_token.get(
@@ -208,7 +212,7 @@ async def start_gateway(
     if not isinstance(descriptors, collections.abc.Iterable):
         descriptors = [descriptors]
     try:
-        logging.info("starting gateway...")
+        logger.info("starting gateway...")
         debug = (
             "DELPHAI_ENVIRONMENT" in os.environ
             and os.environ["DELPHAI_ENVIRONMENT"] == "development"
@@ -240,9 +244,9 @@ async def start_gateway(
                     service_name
                 ]
                 if service_handler.full_name.startswith("grpc."):
-                    logging.info(f"skipping service {service_handler.name}")
+                    logger.info(f"skipping service {service_handler.name}")
                 else:
-                    logging.info(f"processing service {service_handler.name}")
+                    logger.info(f"processing service {service_handler.name}")
                     for method_name in service_handler.methods_by_name.keys():
                         method_get_handler, request_handler = get_http_handlers(
                             descriptor, service_handler.name, method_name, channel
@@ -258,7 +262,7 @@ async def start_gateway(
                             route=request_handler,
                             methods=["post"],
                         )
-                        logging.info(f"  processing {method_name}")
+                        logger.info(f"  processing {method_name}")
                         method_descriptor: MethodDescriptor = (
                             service_handler.methods_by_name[method_name]
                         )
@@ -275,7 +279,7 @@ async def start_gateway(
                                             route=request_handler,
                                             methods=[supported_method],
                                         )
-        logging.info(f"started gateway on port {http_port}")
+        logger.info(f"started gateway on port {http_port}")
         return await serve(app, config)
     except Exception as ex:
-        logging.error(str(ex))
+        logger.error(str(ex))
